<?php

declare(strict_types=1);

namespace Drupal\entity_crud_alter_status_message;

use Drupal\Core\Entity\EntityTypeManagerInterface;

/**
 * Manages the entity crud alter status message.
 */
final class EntityCrudAlterStatusMessageManager implements EntityCrudAlterStatusMessageManagerInterface {

  /**
   * System to Crud mapping for Node.
   *
   * @var array
   */
  public static $crudMappingNode = ['default' => 'Create', 'edit' => 'Update', 'delete' => 'Delete'];

  /**
   * System to Crud mapping for Term.
   *
   * @var array
   */
  public static $crudMappingTerm = ['default' => 'Create', 'edit' => 'Update', 'delete' => 'Delete'];

  /**
   * System to Crud mapping for Media.
   *
   * @var array
   */
  public static $crudMappingMedia = ['add' => 'Create', 'edit' => 'Update', 'delete' => 'Delete'];

  /**
   * Constructs an EntityCrudAlterStatusMessageManager object.
   */
  public function __construct(
    private readonly EntityTypeManagerInterface $entityTypeManager,
  ) {}

  /**
   * Get the entity crud alter status message.
   */
  public function getEntityCrudAlterStatusMessage($entity_type, $bundle, $operation) {
    /** @var \Drupal\entity_crud_alter_status_message\EntityCrudAlterStatusMessageInterface $entity */
    $entity = $this->entityTypeManager->getStorage('entity_crud_alter_status_message')->load($entity_type . '.' . $bundle . '.' . $operation);
    return $entity ? $entity->getMessage() : FALSE;
  }

  /**
   * Get the Crud mapping.
   */
  public function getCrudMapping($entity_type) {
    switch ($entity_type) {
      case 'node':
        return self::$crudMappingNode;

      case 'taxonomy_term':
        return self::$crudMappingTerm;

      case 'media':
        return self::$crudMappingMedia;

      default:
        return [];
    }
  }

  /**
   * Get the entity types available.
   */
  public function getValidEntityTypes() {
    $entity_types = $this->entityTypeManager->getDefinitions();
    $allowed_entity_types = ['node' => 'Node', 'taxonomy_term' => 'Taxonomy term', 'media' => 'Media'];
    $options = [];
    foreach ($allowed_entity_types as $key => $value) {
      if (isset($entity_types[$key])) {
        $options[$key] = $value;
      }
    }
    return $options;
  }

}
