<?php

namespace Drupal\Tests\entity_crud_alter_status_message\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Tests for the Admin section .
 *
 * @group entity_crud_alter_status_message
 */
class EntityCrudAlterStatusMessageAdminTest extends BrowserTestBase {

  use EntityCrudAlterStatusMessageTrait;

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'entity_crud_alter_status_message',
    'node',
  ];

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * The admin user to use during the test.
   *
   * @var \Drupal\user\UserInterface
   */
  private $adminUser;

  /**
   * Perform initial setup tasks that run before every test method.
   */
  public function setUp(): void {
    parent::setUp();
    $this->adminUser = $this->DrupalCreateUser([
      'administer entity_crud_alter_status_message',
    ]);
    $this->drupalCreateContentType([
      'type' => 'article',
      'name' => 'Article',
    ]);
  }

  /**
   * Tests the list builder.
   */
  public function testEntityCrudAlterStatusMessageListBuilder() {
    $this->drupalLogin($this->adminUser);
    $assert_session = $this->assertSession();

    // Create a test entity_crud_alter_status_message.
    $this->createTestEntityCrudAlterStatusMessage(
      'node',
      'article',
      'default',
      'Article node created - testEntityCrudAlterStatusMessageListBuilder test'
    );

    // Go to the listing page.
    $this->drupalGet('admin/config/system/entity-crud-alter-status-message');

    // Verify that the entity_crud_alter_status_message record is displayed.
    $assert_session->pageTextContains('node.article.default');
  }

  /**
   * Tests routes for an authorized user.
   */
  public function testAdminUserRoutes() {

    // Create an entity_crud_alter_status_message.
    $this->createTestEntityCrudAlterStatusMessage('node', 'article', 'default', 'Article node created - test message');

    // Log in as an admin user.
    $this->drupalLogin($this->adminUser);

    // Define the routes to test.
    $basicRoutes = [
      'entity.entity_crud_alter_status_message.collection' => [],
      'entity.entity_crud_alter_status_message.add_form' => [],
      'entity.entity_crud_alter_status_message.edit_form' => ['entity_crud_alter_status_message' => 'node.article.default'],
      'entity.entity_crud_alter_status_message.delete_form' => ['entity_crud_alter_status_message' => 'node.article.default'],
    ];

    // Test the routes.
    $this->routeAccessTest($basicRoutes, 200);
  }

}
