<?php

namespace Drupal\Tests\entity_crud_alter_status_message\Functional;

use Drupal\Core\Url;
use Drupal\entity_crud_alter_status_message\Entity\EntityCrudAlterStatusMessage;
use Drupal\media\Entity\MediaType;
use Drupal\taxonomy\Entity\Vocabulary;

/**
 * Used for entity_crud_alter_status_message access tests.
 *
 * @group entity_crud_alter_status_message
 */
trait EntityCrudAlterStatusMessageTrait {

  /**
   * A entity_crud_alter_status_message entity to use for testing.
   *
   * @var \Drupal\entity_crud_alter_status_message\Entity\EntityCrudAlterStatusMessageInterface
   */
  protected $testEntityCrudAlterStatusMessage;

  /**
   * Tests each route for the currently signed-in user.
   */
  protected function routeAccessTest($routes, $response) {
    foreach ($routes as $route => $parameters) {
      $url = Url::fromRoute($route, $parameters);
      $this->drupalGet($url);
      $this->assertSession()->statusCodeEquals($response);
    }
  }

  /**
   * Make a message entity for testing operations that require a key.
   */
  protected function createTestEntityCrudAlterStatusMessage($entity_type, $bundle, $operation, $message) {
    $this->testEntityCrudAlterStatusMessage = new EntityCrudAlterStatusMessage([
      'id' => $entity_type . '.' . $bundle . '.' . $operation,
      'entity_type' => $entity_type,
      'entity_bundle' => $bundle,
      'crud_action' => $operation,
      'message' => ['value' => $message],
    ], 'entity_crud_alter_status_message');
    $this->testEntityCrudAlterStatusMessage->save();
  }

  /**
   * Create a new vocabulary.
   *
   * @param array $values
   *   Vocabulary properties.
   *
   * @return \Drupal\taxonomy\VocabularyInterface
   *   The Vocabulary object.
   */
  public function addVocabulary(array $values = []) {
    $name = mb_strtolower($this->randomMachineName(5));
    $values += [
      'name' => $name,
      'vid' => $name,
    ];
    $vocabulary = Vocabulary::create($values);
    $vocabulary->save();
    return $vocabulary;
  }

  /**
   * Create a new media type.
   *
   * @param array $values
   *   Media type properties.
   *
   * @return \Drupal\media\MediaTypeInterface
   *   The media type object.
   */
  public function drupalCreateMediaType(array $values = []) {
    $media_type = MediaType::create($values);
    $media_type->save();
    // Create the source field.
    $source_field = $media_type->getSource()->createSourceField($media_type);
    $source_field->getFieldStorageDefinition()->save();
    $source_field->save();
    $media_type
      ->set('source_configuration', [
        'source_field' => $source_field->getName(),
      ])
      ->save();
    return $media_type;
  }

}
