<?php

declare(strict_types=1);

namespace Drupal\Tests\entity_crud_alter_status_message\Unit;

use Drupal\Tests\UnitTestCase;
use Drupal\entity_crud_alter_status_message\EntityCrudAlterStatusMessageManager;

/**
 * @coversDefaultClass Drupal\entity_crud_alter_status_message\EntityCrudAlterStatusMessageManager
 * @group entity_crud_alter_status_message
 */
class EntityCrudAlterStatusMessageManagerTest extends UnitTestCase {

  /**
   * Config.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $config;

  /**
   * Configuration storage.
   *
   * @var \Drupal\Core\Config\Entity\ConfigEntityStorage
   */
  protected $configStorage;

  /**
   * Entity type manager instance.
   *
   * @var \Drupal\Core\Entity\EntityTypeManager
   */
  protected $entityTypeManager;

  /**
   * Container builder.
   *
   * This should be used sparingly by test cases to add to the container as
   * necessary for tests.
   *
   * @var \Drupal\Core\DependencyInjection\ContainerBuilder
   */
  protected $container;

  /**
   * The entity crud alter status message manager.
   *
   * @var \Drupal\entity_crud_alter_status_message\EntityCrudAlterStatusMessageManagerInterface
   */
  private $entityCrudAlterStatusMessageManager;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    // Mock EntityTypeManager service.
    $this->entityTypeManager = $this->createMock('\Drupal\Core\Entity\EntityTypeManager');

    // Create the entity crud alter status message manager.
    $this->entityCrudAlterStatusMessageManager = new EntityCrudAlterStatusMessageManager($this->entityTypeManager);

  }

  /**
   * Test getCrudMapping for node entity type.
   *
   * @covers ::getCrudMapping
   */
  public function testGetCrudMapping() {
    $this->assertEquals(
      $this->entityCrudAlterStatusMessageManager->getCrudMapping('node'),
      ['default' => 'Create', 'edit' => 'Update', 'delete' => 'Delete']
    );
    $this->assertEquals(
      $this->entityCrudAlterStatusMessageManager->getCrudMapping('taxonomy_term'),
      ['default' => 'Create', 'edit' => 'Update', 'delete' => 'Delete']
    );
    $this->assertEquals(
      $this->entityCrudAlterStatusMessageManager->getCrudMapping('media'),
      ['add' => 'Create', 'edit' => 'Update', 'delete' => 'Delete']
    );
  }

}
